Authenticator
===============================

.. currentmodule:: biobroker.authenticator

.. autosummary::
   :nosignatures:

    GenericAuthenticator
    WebinAuthenticator

.. automodule:: biobroker.authenticator
   :members:
   :undoc-members:
   :show-inheritance:

Exceptions
----------

.. automodule:: biobroker.authenticator.exceptions
   :members:
   :undoc-members:
   :show-inheritance:
